# ontologia/codicem/locum/un-locode

- GitHub Issues:
  - https://github.com/HXL-CPLP/forum/issues/57
  - https://github.com/EticaAI/HXL-Data-Science-file-formats/issues/13
- https://github.com/datasets/un-locode
- http://www.unece.org/cefact/locode/welcome.html

<!--
Not so precise? See this discussion:
- https://github.com/datasets/un-locode/issues/19
-->
